aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorRapptz <[email protected]>2019-03-19 09:21:41 -0400
committerRapptz <[email protected]>2019-03-19 09:23:12 -0400
commitc30a366106f9d6114dcf38a31aed58dec6747054 (patch)
tree9c8ddd6760c1f999137b5db1383f262d14320b86
parent[commands] Redesign extension exception flow. (diff)
downloaddiscord.py-c30a366106f9d6114dcf38a31aed58dec6747054.tar.xz
discord.py-c30a366106f9d6114dcf38a31aed58dec6747054.zip
Try to consistently use "inherit" vs "derive" in documentation.
-rw-r--r--discord/errors.py2
-rw-r--r--discord/ext/commands/bot.py6
-rw-r--r--discord/ext/commands/core.py8
-rw-r--r--discord/ext/commands/errors.py10
-rw-r--r--discord/ext/commands/help.py4
5 files changed, 15 insertions, 15 deletions
diff --git a/discord/errors.py b/discord/errors.py
index 963b898d..6669e168 100644
--- a/discord/errors.py
+++ b/discord/errors.py
@@ -130,7 +130,7 @@ class InvalidArgument(ClientException):
is invalid some way (e.g. wrong value or wrong type).
This could be considered the analogous of ``ValueError`` and
- ``TypeError`` except derived from :exc:`ClientException` and thus
+ ``TypeError`` except inherited from :exc:`ClientException` and thus
:exc:`DiscordException`.
"""
pass
diff --git a/discord/ext/commands/bot.py b/discord/ext/commands/bot.py
index fc22475d..6de6b5bb 100644
--- a/discord/ext/commands/bot.py
+++ b/discord/ext/commands/bot.py
@@ -182,7 +182,7 @@ class BotBase(GroupMixin):
This function can either be a regular function or a coroutine.
Similar to a command :func:`.check`\, this takes a single parameter
- of type :class:`.Context` and can only raise exceptions derived from
+ of type :class:`.Context` and can only raise exceptions inherited from
:exc:`.CommandError`.
Example
@@ -255,7 +255,7 @@ class BotBase(GroupMixin):
This function can either be a regular function or a coroutine.
Similar to a command :func:`.check`\, this takes a single parameter
- of type :class:`.Context` and can only raise exceptions derived from
+ of type :class:`.Context` and can only raise exceptions inherited from
:exc:`.CommandError`.
Example
@@ -963,7 +963,7 @@ class Bot(BotBase, discord.Client):
pass
class AutoShardedBot(BotBase, discord.AutoShardedClient):
- """This is similar to :class:`.Bot` except that it is derived from
+ """This is similar to :class:`.Bot` except that it is inherited from
:class:`discord.AutoShardedClient` instead.
"""
pass
diff --git a/discord/ext/commands/core.py b/discord/ext/commands/core.py
index 3f413075..3074e0ca 100644
--- a/discord/ext/commands/core.py
+++ b/discord/ext/commands/core.py
@@ -135,7 +135,7 @@ class Command(_BaseCommand):
checks
A list of predicates that verifies if the command could be executed
with the given :class:`.Context` as the sole parameter. If an exception
- is necessary to be thrown to signal failure, then one derived from
+ is necessary to be thrown to signal failure, then one inherited from
:exc:`.CommandError` should be used. Note that if the checks fail then
:exc:`.CheckFailure` exception is raised to the :func:`.on_command_error`
event.
@@ -1336,7 +1336,7 @@ def has_permissions(**perms):
:class:`.discord.Permissions`.
This check raises a special exception, :exc:`.MissingPermissions`
- that is derived from :exc:`.CheckFailure`.
+ that is inherited from :exc:`.CheckFailure`.
Parameters
------------
@@ -1402,7 +1402,7 @@ def bot_has_permissions(**perms):
the permissions listed.
This check raises a special exception, :exc:`.BotMissingPermissions`
- that is derived from :exc:`.CheckFailure`.
+ that is inherited from :exc:`.CheckFailure`.
"""
def predicate(ctx):
guild = ctx.guild
@@ -1424,7 +1424,7 @@ def guild_only():
using the command.
This check raises a special exception, :exc:`.NoPrivateMessage`
- that is derived from :exc:`.CheckFailure`.
+ that is inherited from :exc:`.CheckFailure`.
"""
def predicate(ctx):
diff --git a/discord/ext/commands/help.py b/discord/ext/commands/help.py
index 78c16717..999ef7b0 100644
--- a/discord/ext/commands/help.py
+++ b/discord/ext/commands/help.py
@@ -770,7 +770,7 @@ class HelpCommand:
class DefaultHelpCommand(HelpCommand):
"""The implementation of the default help command.
- This derives from :class:`HelpCommand`.
+ This inherits from :class:`HelpCommand`.
It extends it with the following attributes.
@@ -973,7 +973,7 @@ class DefaultHelpCommand(HelpCommand):
class MinimalHelpCommand(HelpCommand):
"""An implementation of a help command with minimal output.
- This derives from :class:`HelpCommand`.
+ This inherits from :class:`HelpCommand`.
Attributes
------------
diff --git a/discord/ext/commands/errors.py b/discord/ext/commands/errors.py
index bb58fcdd..574dca9f 100644
--- a/discord/ext/commands/errors.py
+++ b/discord/ext/commands/errors.py
@@ -43,7 +43,7 @@ class CommandError(DiscordException):
This inherits from :exc:`discord.DiscordException`.
- This exception and exceptions derived from it are handled
+ This exception and exceptions inherited from it are handled
in a special way as they are caught and passed into a special event
from :class:`.Bot`\, :func:`on_command_error`.
"""
@@ -237,7 +237,7 @@ class BadUnionArgument(UserInputError):
class ArgumentParsingError(UserInputError):
"""An exception raised when the parser fails to parse a user's input.
This derives from :exc:`UserInputError`. There are child classes
that implement more granular parsing errors for i18n purposes.
"""
pass
@@ -245,7 +245,7 @@ class ArgumentParsingError(UserInputError):
class UnexpectedQuoteError(ArgumentParsingError):
"""An exception raised when the parser encounters a quote mark inside a non-quoted string.
- This derives from :exc:`ArgumentParsingError`.
+ This inherits from :exc:`ArgumentParsingError`.
Attributes
------------
@@ -260,7 +260,7 @@ class InvalidEndOfQuotedStringError(ArgumentParsingError):
"""An exception raised when a space is expected after the closing quote in a string
but a different character is found.
- This derives from :exc:`ArgumentParsingError`.
+ This inherits from :exc:`ArgumentParsingError`.
Attributes
-----------
@@ -274,7 +274,7 @@ class InvalidEndOfQuotedStringError(ArgumentParsingError):
class ExpectedClosingQuoteError(ArgumentParsingError):
"""An exception raised when a quote character is expected but not found.
- This derives from :exc:`ArgumentParsingError`.
+ This inherits from :exc:`ArgumentParsingError`.
Attributes
-----------
@@ -237,7 +237,7 @@ class BadUnionArgument(UserInputError):
class ArgumentParsingError(UserInputError):
"""An exception raised when the parser fails to parse a user's input.
- This derives from :exc:`UserInputError`. There are child classes
+ This inherits from :exc:`UserInputError`. There are child classes
that implement more granular parsing errors for i18n purposes.
"""